function object = flt_holdlast( init, input )

% object = flt_holdlast( init, input )
%
% Will keep the last input values and return them as many times as
% requested. If no input values have been read yet, then 'init' value will
% be returned.
%
% The input may have multiple channels. In this case the 'init' should be a
% vector with length equal to channel count.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% define the class so that matlab recognizes it when loading objects
if nargin == 0
  this.last_vals    = [];
  this.nan_vals     = [];
  object = class( this, 'flt_holdlast', flt );
  return;
end


nchannels = get_nchannels(input);


this.last_vals    = init;
this.nan_vals     = NaN * zeros( 1, nchannels );


object = class( this, 'flt_holdlast', flt(input) );
return;
