function ind = find_or_create( vars )

% ind = find_or_create( vars )
%
% Returns the index of the group containing variables 'vars'. If the group
% doesn't exist in the group cache, one will be created. If the group had to
% be created, then its model will be in precomputed state.
%
% Note: if the group has to be created, its model will be very low quality!


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global State;


vars = sort( vars );

ind = find_group_entry( State, vars );
if ind == 0
  ind = add_group( vars );
end

return;








function ind = find_group_entry(State, Vars)

% Returns the index of a group entry that has the variables Vars.
% If there is no such group, returns zero.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ind   = 0;

% return if there are no groups
if size(State.Groups, 1) == 0, return; end

l     = length(Vars);
F     = find(State.Hash == Vars(1));

for i = F
  if (length(State.Groups(i).Vars) == l) && all(Vars == State.Groups(i).Vars)
    % found the group
    ind = i;
    return;
  end
end

% no such group, return 0
return;








function ind = add_group( vars )

% ind = add_group( vars )
%
% Adds a new group to the Group table. The new group's Vars field
% is filled. Its model is tuned as little as the modeler allows.
% The group is left inactive.
%
% Note: the group will be in precomputed state!

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global State;


vars         = sort(vars);               % variables must always be sorted
ind          = length(State.Hash) + 1;   % the new group is the nth group

% Insert variables and make an empty model
State.Groups(ind).Vars  = vars;
State.Groups(ind).Model = make_model( vars, ...
                                      State.modeler_class, ...
                                      State.modeler_settings );

% Insert the first variable into the hash table
State.Hash(ind) = vars(1);

return;
